/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart;

/**
 * A common interface for the basic graphic operations that need to be
 * implemented for DefaultChart to work properly. Basically this interface was
 * introduced to let the entire library work on frameworks different from
 * Swing/AWT.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public interface GraphicsI {
    /**
     * Changes the color used to draw the foreground objects in this DefaultChart. The
     * object passed must be compatible with the underlying implementation (eg.
     * created with one of the methods in this interface).
     * 
     * @param c
     *            the new color
     */
    void setColor(Object c);

    /**
     * Draws a line from (x1,y1) to (x2,y2) (coordinate in pixels).
     * 
     * @param x1
     *            the first point's abscissa
     * @param y1
     *            the first point's ordinate
     * @param x2
     *            the second point's abscissa
     * @param y2
     *            the second point's ordinate
     */
    void drawLine(int x1, int y1, int x2, int y2);

    /**
     * Draws a string starting at the given point.
     * 
     * @param s
     *            the String to be drawn
     * @param x
     *            top-left corner's abscissa
     * @param y
     *            top-left corner's ordinate
     */
    void drawString(String s, int x, int y);

    /**
     * Draws a filled polygon.
     * 
     * @param xPoints
     *            array of the vertices' abscissae
     * @param yPoints
     *            array of the vertices' ordinates
     * @param n
     *            number of vertices
     */
    void fillPolygon(int[] xPoints, int[] yPoints, int n);

    /**
     * Draws a circle with the specified center and radius.
     * 
     * @param x
     *            the center's abscissa
     * @param y
     *            the center's ordinate
     * @param radius
     *            the radius
     */
    void drawCircle(int x, int y, int radius);

    /**
     * Returns the width in pixels of a drawn string.
     * 
     * @param s
     *            the string
     * @return the string's width
     */
    int getStringWidth(String s);

    /**
     * Returns the maximum height of a drawn string (in pixels).
     * 
     * @return the string's height
     */
    int getStringHeight();

    /**
     * Returns the black color (an object representing the black color
     * compatible with the underlying implementation).
     * 
     * @return the black color
     */
    Object getBlackColor();

    /**
     * Returns a random color from the underlying implementation.
     * 
     * @return a color object
     */
    Object getRandomColor();
}